AadhaarMaskFormatter class

Custom TextInputFormatter for Aadhaar masking Masks first 8 digits and shows only last 4 digits

Inheritance

Constructors

AadhaarMaskFormatter({int visibleDigits = 4, String maskChar = '*'})

Properties

hashCode int
The hash code for this object.
no setterinherited
maskChar String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleDigits int
final

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited