AsyncValidatorFunction typedef

AsyncValidatorFunction = Future<Map<String, dynamic>?> Function(AbstractControl control)

Signature of a function that receives a control and returns a Future that emits validation errors if present, otherwise null.

Implementation

typedef AsyncValidatorFunction =
    Future<Map<String, dynamic>?> Function(AbstractControl<dynamic> control);