ButtonProps class

Constructors

ButtonProps({required String label, VoidCallback? onPressed, Color? backgroundColor, Color? foregroundColor, double borderRadius = 8.0, EdgeInsetsGeometry? padding, bool disabled = false})
const

Properties

backgroundColor Color?
final
borderRadius double
final
disabled bool
final
foregroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
onPressed VoidCallback?
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited