ConsentForm class

Inheritance

Constructors

ConsentForm({Key? key, required String aadhaarmethod, required String aadhaarNumber, required String assetPath, required String url, String? aadhaarResponseassetspath, String? aadhaarResponseApiurl, required String leadId, required String token, required bool isOffline, required String aadharvaultlookupassetpath, required String aadharvaultlookupapiurl, required String aadharvaultassetpath, required String aadharvaultApiurl})
const

Properties

aadhaarmethod String
final
aadhaarNumber String
final
aadhaarResponseApiurl String?
final
aadhaarResponseassetspath String?
final
aadharvaultApiurl String
final
aadharvaultassetpath String
final
aadharvaultlookupapiurl String
final
aadharvaultlookupassetpath String
final
assetPath String
final
hashCode int
The hash code for this object.
no setterinherited
isOffline bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
url String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ConsentForm>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited