ConstantVariable class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- camelSuccess → const String
- capitalResponse → const String
- consentBioMetricString → const String
- consentOTPGendrateFailedString → const String
- consentOTPSendSuccessfullyString → const String
- consentOTPString → const String
- consentOTPVerificationString → const String
- consentTermsConditionString → const String
- failedString → const String
- lowerSuccess → const String
- noDataProviderString → const String
- offlineHandlerloadString → const String
- otpString → const String
- responseCode → const String
- responseData → const String
- status → const String
- statusCode101 → const String
- statusCode200 → const String
- verificationFaildString → const String
- verifiedString → const String
- verifiedSuccessfullyString → const String
- verifyOTPString → const String
- verifyString → const String