isNull static method
Returns true if control is null, otherwise return false.
Implementation
static bool isNull(AbstractControl<dynamic> control) => control.value == null;
Returns true if control is null, otherwise return false.
static bool isNull(AbstractControl<dynamic> control) => control.value == null;