isNotNull property
bool
get
isNotNull
Returns true is the value of the control is not null, otherwise returns false.
Implementation
bool get isNotNull => Control.isNotNull(this);
Returns true is the value of the control is not null, otherwise returns false.
bool get isNotNull => Control.isNotNull(this);