addAll method
void
addAll(
- List<
AbstractControl< controls, {T> > - bool updateParent = true,
- bool emitEvent = true,
Appends all controls to the end of this array.
When updateParent is true or not supplied (the default) each change
affects this control and its parent, otherwise only affects to this
control.
When emitEvent is true or not supplied (the default), both the
statusChanges and valueChanges emit events with the latest status
and value when the control is reset. When false, no events are emitted.
Implementation
void addAll(
List<AbstractControl<T>> controls, {
bool updateParent = true,
bool emitEvent = true,
}) {
_controls.addAll(controls);
for (final control in controls) {
control.parent = this;
}
updateValueAndValidity(updateParent: updateParent, emitEvent: emitEvent);
emitsCollectionChanged(_controls);
}