defaultValue property

T? get defaultValue

Gets the default value of the control.

This value is determined by the value and nonNullable arguments passed to the constructor:

  • If nonNullable is true (the default), this holds the initial value.
  • If nonNullable is false, this is null.

When reset is called without a value, the control resets to this value.

Implementation

T? get defaultValue => _defaultValue;