FormProps class

Constructors

FormProps({required String formControlName, required String label, String? hint, bool mandatory = false, int? maxLength, ValidationFunction? validator})
const

Properties

formControlName String
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
label String
final
mandatory bool
final
maxLength int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator ValidationFunction?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited