GstResponseParser class
Parser for GST verification responses
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseOfflineResponse(
dynamic responseData) → bool -
Parse offline asset response and return success status
override
-
parseOnlineResponse(
dynamic responseData) → bool -
Parse online API response and return success status
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited