InputValidationManager class

Manages input validation state

Constructors

InputValidationManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPattern(RegExp pattern) → void
Add validation pattern
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Reset validation
toString() String
A string representation of this object.
inherited
validate(String input) bool
Validate input against patterns

Operators

operator ==(Object other) bool
The equality operator.
inherited