KYCService class

Inheritance

Constructors

KYCService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify({required bool isOffline, String? request, String? url, String? assetPath}) Future<Response>
verifyOffline(String assetPath) Future<Response>
inherited
verifyOnline(String url) Future<Response>
inherited
verifyOnlineWithData(String url, dynamic data) Future<Response>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited