allowNegatives property
Whether the validator allows negative numbers.
If set to true, the validator will accept strings representing
negative numbers (prefixed with a '-'). Defaults to true.
Implementation
final bool allowNegatives;
Whether the validator allows negative numbers.
If set to true, the validator will accept strings representing
negative numbers (prefixed with a '-'). Defaults to true.
final bool allowNegatives;