allowedDecimals property

int allowedDecimals
final

The allowed number of decimal places in the validated string.

This value specifies the maximum number of digits allowed after the decimal point in the validated string. Defaults to 0 (no decimals).

Implementation

final int allowedDecimals;