OneOfValidator class

Represents a validator that requires the control's value to be one of the values in the provided collection.

For String values, the comparison can be made case-sensitive or insensitive using the caseSensitive parameter. For other types, this parameter is ignored.

Inheritance

Constructors

OneOfValidator(List collection, {bool caseSensitive = true})
Constructs an instance of OneOfValidator.

Properties

caseSensitive bool
final
collection List
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(AbstractControl control) Map<String, dynamic>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(AbstractControl control) Map<String, dynamic>?
Validates the control.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited