OneOfValidator constructor

OneOfValidator(
  1. List collection, {
  2. bool caseSensitive = true,
})

Constructs an instance of OneOfValidator.

The collection parameter is the list of allowed values. The caseSensitive parameter determines if string comparison should be case-sensitive. Defaults to true.

Implementation

OneOfValidator(this.collection, {this.caseSensitive = true});