hasCustomInputDecoration property
if true, custom Input decoration that is passed in takes effect
Implementation
final bool hasCustomInputDecoration;
if true, custom Input decoration that is passed in takes effect
final bool hasCustomInputDecoration;