PanVerificationHandler class

Handler for PAN verification

Inheritance

Constructors

PanVerificationHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify({required bool isOffline, String? url, String? assetPath, dynamic request}) Future<Response>
Unified verification method
inherited
verifyOffline(String assetPath) Future<Response>
Handle offline verification via asset
override
verifyOnline(String url, {dynamic request}) Future<Response>
Handle online verification via API
override

Operators

operator ==(Object other) bool
The equality operator.
inherited