PanidRequest class

Constructors

PanidRequest({required String pan, String consent = "Y"})
const
PanidRequest.fromJson(String source)
factory
PanidRequest.fromMap(Map<String, dynamic> map)
factory

Properties

final
hashCode int
The hash code for this object.
no setteroverride
pan String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? pan, String? consent}) PanidRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override