ReactiveDatePickerBuilder<T> typedef

ReactiveDatePickerBuilder<T> = Widget Function(BuildContext context, ReactiveDatePickerDelegate<T> picker, Widget? child)

A builder that builds a widget responsible to decide when to show the picker dialog.

The builder passes a delegate picker as argument that has a method to show the dialog, it also has a property to access the FormControl that is bound to ReactiveTimePicker.

See also ReactiveDatePickerDelegate.

Implementation

typedef ReactiveDatePickerBuilder<T> =
    Widget Function(
      BuildContext context,
      ReactiveDatePickerDelegate<T> picker,
      Widget? child,
    );