ReactiveForm<T> class

This class is responsible for create a FormControlInheritedStreamer for exposing a FormGroup to all descendants widgets.

It also configures the inner FormControlInheritedStreamer to rebuild context each time the FormGroup.status changes.

The optional type argument T allows for specifying the type of result that can be returned when a route associated with this form is popped.

Inheritance
Annotations

Constructors

ReactiveForm({Key? key, required FormGroup formGroup, required Widget child, ReactiveFormCanPopCallback? canPop, ReactiveFormPopInvokedWithResultCallback<T>? onPopInvokedWithResult})
Creates and instance of ReactiveForm.
const

Properties

canPop ReactiveFormCanPopCallback?
Determine whether a route can popped. See PopScope for more details.
final
child Widget
The widget below this widget in the tree.
final
formGroup FormGroup
The form group control that is bound to this widget.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPopInvokedWithResult ReactiveFormPopInvokedWithResultCallback<T>?
A callback invoked when a route is popped. See PopScope for more details.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context, {bool listen = true}) AbstractControl<Object>?
Returns the nearest model up its widget tree.