ReactiveFormArray<T> constructor
const
ReactiveFormArray<T> ({
- Key? key,
- required ReactiveFormArrayBuilder<
T> builder, - String? formArrayName,
- FormArray<
T> ? formArray, - Widget? child,
Creates an instance of ReactiveFormArray.
The builder argument is required.
The child is optional but is good practice to use if part of the widget
subtree does not depend on the value of the FormArray that is bind
with this widget.
Implementation
const ReactiveFormArray({
super.key,
required this.builder,
this.formArrayName,
this.formArray,
this.child,
}) : assert(
(formArrayName != null && formArray == null) ||
(formArrayName == null && formArray != null),
'Must provide a formArrayName or a formArray, but not both at the same time.',
);