focusNode property
FocusNode?
get
focusNode
An object that can be used by a stateful widget to obtain the keyboard focus.
Implementation
FocusNode? get focusNode => widget.focusNode;
An object that can be used by a stateful widget to obtain the keyboard focus.
FocusNode? get focusNode => widget.focusNode;