RegExpPatternEvaluator class
Evaluates a pattern using a RegExp.
- Implemented types
Constructors
- RegExpPatternEvaluator(RegExp regExp)
-
Constructs an instance of the class.
The argument
regExpmust not be null.const
Properties
Methods
-
hasMatch(
String input) → bool -
Evaluates if the the patter has a match with the
inputoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited