StringControlExtension extension
This is an extension on AbstractControl<String>.
Brings to AbstractControl<String> methods like isNullOrEmpty and isNotNullOrEmpty.
Properties
- isNotNullOrEmpty → bool
-
Available on AbstractControl<
Returns true if the value of the control is not null and is not an empty white spaces string, otherwise returns false.String> , provided by the StringControlExtension extensionno setter - isNullOrEmpty → bool
-
Available on AbstractControl<
Returns true if the value of the control is null or an empty white spaces string, otherwise returns false.String> , provided by the StringControlExtension extensionno setter