ValidatorException constructor
ValidatorException(
- String message
Constructs an instance of the exception with the provided message.
Implementation
ValidatorException(this.message);
Constructs an instance of the exception with the provided message.
ValidatorException(this.message);