ValidatorFunction typedef

ValidatorFunction = Map<String, dynamic>? Function(AbstractControl control)

Signature of a function that receives a control and synchronously returns a map of validation errors if present, otherwise null.

Implementation

typedef ValidatorFunction =
    Map<String, dynamic>? Function(AbstractControl<dynamic> control);