minLength static method

Validator minLength(
  1. int minLength
)

Creates a validator that requires the length of the control's value to be greater than or equal to the provided minLength.

The argument minLength argument must not be null.

Implementation

static Validator<dynamic> minLength(int minLength) =>
    MinLengthValidator(minLength);