ValueAccessorException constructor
ValueAccessorException(
- String message
Constructs an instance of the exception with the provided message.
Implementation
ValueAccessorException(this.message);
Constructs an instance of the exception with the provided message.
ValueAccessorException(this.message);