ApiClient class

Refactored ApiClient with better separation of concerns

Constructors

ApiClient({Dio? dioInstance, bool enableLogging = true})

Properties

dio Dio
final
enableLogging bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callGet(String url) Future<Response>
callPost(String url, {dynamic data}) Future<Response>
Deprecated methods kept for backward compatibility
get(String url) Future<Response>
Perform GET request
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String url, {dynamic data}) Future<Response>
Perform POST request with optional data
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited