ControlExtension extension
This is an extension on AbstractControl.
Brings to AbstractControl methods like isNull and isNotNull.
Properties
- isNotNull → bool
-
Available on AbstractControl, provided by the ControlExtension extension
Returns true is the value of the control is not null, otherwise returns false.no setter - isNull → bool
-
Available on AbstractControl, provided by the ControlExtension extension
Returns true is the value of the control is null, otherwise returns false.no setter