DebouncedAsyncValidator constructor
DebouncedAsyncValidator(
- AsyncValidator _validator,
- int _debounceTime
Creates a new instance of the DebouncedAsyncValidator class.
The validator is the async validator to be debounced.
The debounceTime is the duration in milliseconds to wait before
validating the control.
Implementation
DebouncedAsyncValidator(this._validator, this._debounceTime)
: assert(_debounceTime >= 0);