FilterArgs class
Filter arguments
Constructors
- FilterArgs(bool isResponse, dynamic data)
-
Default constructor
const
Properties
- data → dynamic
-
if the isResponse is false, the data is the RequestOptions.data
if the isResponse is true, the data is the Response.data
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasJsonData → bool
-
Returns true if the data is a json data
no setter
- hasListData → bool
-
Returns true if the data is a list
no setter
- hasMapData → bool
-
Returns true if the data is a map
no setter
- hasStringData → bool
-
Returns true if the data is a string
no setter
- hasUint8ListData → bool
-
Returns true if the data is a Uint8List
no setter
- isResponse → bool
-
If the filter is for a request or response
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited