KYCTextBox class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- KYCTextBox
Constructors
-
KYCTextBox({Key? key, Key? fieldKey, required FormProps formProps, required StyleProps styleProps, bool showVerifyButton = false, ReactiveFormFieldCallback<
String> ? onChange, required ButtonProps buttonProps, required bool isOffline, String? assetPath, required ValueChanged onSuccess, required ValueChanged onError, String? apiUrl, required VerificationType verificationType, String? kycNumber, String? validationPatternErrorMessage, required RegExp? validationPattern, String? otpGendrateassetPath, required String otpGendraassetApiurl, required String aadhaarResponseassetspath, required String aadhaarResponseApiurl, required String aadharvaultassetpath, required String aadharvaultApiurl, required String aadharvaultlookupassetpath, required String aadharvaultlookupapiurl, required String leadId, required String token, bool obscureText = false, bool maskAadhaar = false, List<String> ? usedAadhaarRefNumbers}) -
const
Properties
- aadhaarResponseApiurl → String
-
final
- aadhaarResponseassetspath → String
-
final
- aadharvaultApiurl → String
-
final
- aadharvaultassetpath → String
-
final
- aadharvaultlookupapiurl → String
-
final
- aadharvaultlookupassetpath → String
-
final
- apiUrl → String?
-
final
- assetPath → String?
-
final
-
final
- fieldKey → Key?
-
final
- formProps → FormProps
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOffline → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- kycNumber → String?
-
final
- leadId → String
-
final
- maskAadhaar → bool
-
final
- obscureText → bool
-
final
-
onChange
→ ReactiveFormFieldCallback<
String> ? -
final
- onError → ValueChanged
-
final
- onSuccess → ValueChanged
-
final
- otpGendraassetApiurl → String
-
final
- otpGendrateassetPath → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showVerifyButton → bool
-
final
- styleProps → StyleProps
-
final
- token → String
-
final
-
usedAadhaarRefNumbers
→ List<
String> ? -
final
- validationPattern → RegExp?
-
final
- validationPatternErrorMessage → String?
-
final
- verificationType → VerificationType
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited