ReactiveFormArrayBuilder<T> typedef

ReactiveFormArrayBuilder<T> = Widget Function(BuildContext context, FormArray<T> formArray, Widget? child)

Called to obtain the child widget. This is the signature of a function that receives the context, the formArray and an optional child and returns a Widget.

Implementation

typedef ReactiveFormArrayBuilder<T> =
    Widget Function(
      BuildContext context,
      FormArray<T> formArray,
      Widget? child,
    );