onPopInvokedWithResult property
A callback invoked when a route is popped. See PopScope for more details.
This uses the type argument T to define the type of the result. If T
is not specified, it defaults to dynamic. This parameter is optional
and allows for handling results with specific data types when a route is
popped.
Implementation
final ReactiveFormPopInvokedWithResultCallback<T>? onPopInvokedWithResult;