isNotNullOrEmpty property
bool
get
isNotNullOrEmpty
Returns true if the value of the control is not null and is not an empty white spaces string, otherwise returns false.
Implementation
bool get isNotNullOrEmpty => Control.isNotNullOrEmpty(this);